@@ -218,12 +218,13 @@ sub search {
     $self->log->debug( "Searching: $params{query}" );
     my $path = '/search.json?query=' . uri_encode( $params{query} ) . "&sort_by=$params{sort_by}&sort_order=$params{sort_order}";
 
-    my @results = $self->_paged_get_request_from_api(
+    my %request_params = {
         field   => 'results',
         method  => 'get',
 	path    => $path,
-        size    => $params{size},
-        );
+    };
+    $request_params{size} = $params{size} if( $params{size} );
+    my @results = $self->_paged_get_request_from_api( %request_params );
 
     $self->log->debug( "Got " . scalar( @results ) . " results from query" );
     return @results;
